"use strict";
this.name        = "andromeda";
this.author      = "Norby";
this.copyright   = "2014 Norbert Nagy";
this.licence     = "CC BY-NC-SA 4.0";
this.description = "Create an Andromeda spaceship next to main station.";
this.version     = "1.3";

//customizable properties
this.$AndromedaMaxFuelReserve = 50; //in light years
this.$AndromedaFuelCost = 3; //credits for each light year fuel
this.$AndromedaReFuelDistance = 5000; //m far from the main station

//internal properties, should not touch
this.$AndromedaFuelReserve = 0;
this.$AndromedaShip = null; //store the created sunskimmer ship to prevent recreates
this.$AndromedaTimer = null;

//world script events

this.startUp = function() {	
//	player.replaceShip("andromeda-player", 0); //debug: player will start in an Andromeda
	this.$AndromedaFuelReserve = missionVariables.$AndromedaFuelReserve;
	if( !this.$AndromedaFuelReserve ) this.$AndromedaFuelReserve = this.$AndromedaMaxFuelReserve;
	this.$AndromedaSoundRefuel = new SoundSource;
	this.$AndromedaSoundRefuel.sound = "buy.ogg"; //refuel sound
	this.$AndromedaSoundRefuel.loop = false;
	this.$AndromedaSoundRefuel.repeatCount = 1;	
	this.$AndromedaTimer = new Timer(this, this.$Andromeda_Timed.bind(this), 2, 2);
}

this.playerWillSaveGame = function(message) {
        missionVariables.$AndromedaFuelReserve = this.$AndromedaFuelReserve;
}

//Andromeda functions
this.$Andromeda_Timed = function() {
	var m = system.mainStation;
	if( m && m.isValid && ( !this.$AndromedaShip || !this.$AndromedaShip.isValid ) ) { //delayed create
		this.$AndromedaShip = system.addShips("andromeda", 1, m.position, 500000)[0]; //sunskimmer
//		this.$AndromedaShip.setAI("nullAI.plist");//debug
	}

	if(player.ship.dataKey == "andromeda-player") {
		if( player.ship.fuel <= 6 ) { //refuel from reserves
			if( this.$AndromedaFuelReserve > 0 ) {
				player.ship.fuel += 1;
				this.$AndromedaFuelReserve -= 1;
				if( this.$AndromedaFuelReserve <= 0 ) {
					player.consoleMessage("Your fuel reserves are empty, "
						+"you should target a station and stop within "
						+(this.$AndromedaReFuelDistance/1000)
						+"km for refuel.", 10);
				} else player.consoleMessage(this.$AndromedaFuelReserve
					+" ly fuel left in reserves.", 10);
			}
		}
		var t = player.ship.target;
		if( t && t.isValid && t.isStation ) m = t; //else main station
		if( m && m.isValid && player.ship.speed < 0.1 //stop near a main station for refuel
			&& this.$AndromedaFuelReserve < this.$AndromedaMaxFuelReserve ) {
			var mdist = m.position.distanceTo(player.ship.position) - m.collisionRadius;			
			//player.consoleMessage(mdist,1);//debug
			if( mdist < this.$AndromedaReFuelDistance ) {
				var maxcost = this.$AndromedaMaxFuelReserve * this.$AndromedaFuelCost;
				if( player.credits >= maxcost ) {
					var f = this.$AndromedaMaxFuelReserve - this.$AndromedaFuelReserve;
					var cr = f * this.$AndromedaFuelCost;
					this.$AndromedaFuelReserve = this.$AndromedaMaxFuelReserve; //up to full
					player.credits -= cr; //cost of the refill
					this.$AndromedaSoundRefuel.play(); //refuel sound
					player.consoleMessage("Payed "+cr+" credits for "+f+" ly reserve fuel.", 10);
				} else {
					player.consoleMessage("You must have at least "+maxcost
						+" credits before you can get reserve fuel.", 10);
				}
			}
		}
	}
}
